%global pypi_name packaging

%bcond_with bootstrap

%if %{without bootstrap}
%bcond_without docs
%bcond_without tests
%else
%bcond_with docs
%bcond_with tests
%endif

Summary:        Core utilities for Python packages
Name:           python-%{pypi_name}
Version:        23.1
Release:        3%{?dist}
License:        BSD or ASL 2.0
URL:            https://github.com/pypa/packaging
Source0:        %{url}/archive/%{version}/%{pypi_name}-%{version}.tar.gz

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  pyproject-rpm-macros

%if %{with bootstrap}
BuildRequires:  python%{python3_pkgversion}-setuptools
%endif

%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-pretend
%endif
%if %{with docs}
BuildRequires:  python%{python3_pkgversion}-sphinx
%endif

BuildArch:      noarch

%description
python-packaging provides core utilities for Python
packages like utilities for dealing with versions,
specifiers, markers etc.

%package -n python%{python3_pkgversion}-%{pypi_name}
Summary:        Core utilities for Python packages

%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(packaging) = %{version}
Provides:       python%{python3_version}dist(packaging) = %{version}
Requires:       python%{python3_version}dist(pyparsing)
Requires:       python(abi) = %{python3_version}
%endif

%description -n python%{python3_pkgversion}-%{pypi_name}
python-packaging provides core utilities for Python
packages like utilities for dealing with versions,
specifiers, markers etc.

%if %{with docs}
%package -n python-%{pypi_name}-doc
Summary:        python-packaging documentation

%description -n python-%{pypi_name}-doc
Documentation for python-packaging
%endif


%prep
%autosetup -p1 -n %{pypi_name}-%{version}
sed -i '/html_theme = "furo"/d' docs/conf.py

%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires -r
%endif


%build
%if %{with bootstrap}
%py3_build
%else
%pyproject_wheel
%endif

%if %{with docs}
sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
rm -rf html/_static/fonts/
%endif


%install
%if %{with bootstrap}
%py3_install
echo '%{python3_sitelib}/packaging*' > %{pyproject_files}
%else
%pyproject_install
%pyproject_save_files %{pypi_name}
%endif


%if %{with tests}
%check
%pytest
%endif


%files -n python%{python3_pkgversion}-%{pypi_name} -f %{pyproject_files}
%license LICENSE LICENSE.APACHE LICENSE.BSD
%doc README.rst CHANGELOG.rst CONTRIBUTING.rst

%if %{with docs}
%files -n python-%{pypi_name}-doc
%license LICENSE LICENSE.APACHE LICENSE.BSD
%doc html
%endif


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.1-3
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.1-2
- Rebuilt for loongarch release

* Thu Sep 21 2023 Shuo Wang <abushwang@tencent.com> - 23.1-1
- update to 23.1

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 21.3-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 21.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 21.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 21.3-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Oct 28 2022 Miaojun Dong <zoedong@tencent.com> - 21.3-1
- Initial build

